@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 """Command-line tool to manage CPython Misc/NEWS.d entries."""
-__version__ = "1.0.8"
+__version__ = "1.1.0"
 
 ##
 ## blurb version 1.0
@@ -46,13 +46,14 @@ __version__ = "1.0.8"
 import atexit
 import base64
 import builtins
-from collections import OrderedDict
 import glob
 import hashlib
+import io
 import inspect
 import itertools
 import math
 import os
+from pathlib import Path
 import re
 import shlex
 import shutil
@@ -61,9 +62,7 @@ import sys
 import tempfile
 import textwrap
 import time
-import types
 import unittest
-import uuid
 
 
 #
@@ -74,9 +73,9 @@ import uuid
 template = """
 
 #
-# Please enter the relevant bugs.python.org issue number here:
+# Please enter the relevant GitHub issue number here:
 #
-.. bpo:
+.. gh-issue:
 
 #
 # Uncomment one of these "section:" lines to specify which section
@@ -95,7 +94,7 @@ template = """
 #.. section: C API
 
 # Write your Misc/NEWS entry below.  It should be a simple ReST paragraph.
-# Don't start with "- Issue #<n>: " or "- bpo-<n>: " or that sort of stuff.
+# Don't start with "- Issue #<n>: " or "- gh-issue-<n>: " or that sort of stuff.
 ###########################################################################
 
 
@@ -112,32 +111,6 @@ for line in template.split('\n'):
         sections.append(section.strip())
 
 
-def f(s):
-    """
-    Basic support for 3.6's f-strings, in 3.5!
-
-    Formats "s" using appropriate globals and locals
-    dictionaries.  This f-string:
-        f"hello a is {a}"
-    simply becomes
-        f("hello a is {a}")
-    In other words, just throw parentheses around the
-    string, and you're done!
-
-    Implemented internally using str.format_map().
-    This means it doesn't support expressions:
-        f("two minus three is {2-3}")
-    And it doesn't support function calls:
-        f("how many elements? {len(my_list)}")
-    But most other f-string features work.
-    """
-    frame = sys._getframe(1)
-    d = dict(builtins.__dict__)
-    d.update(frame.f_globals)
-    d.update(frame.f_locals)
-    return s.format_map(d)
-
-
 def sanitize_section(section):
     """
 Cleans up a section string, making it viable as a directory name.
@@ -250,10 +223,10 @@ def sortable_datetime():
 
 
 def prompt(prompt):
-    return input(f("[{prompt}> "))
+    return input(f"[{prompt}> ")
 
 def require_ok(prompt):
-    prompt = f("[{prompt}> ")
+    prompt = f"[{prompt}> "
     while True:
         s = input(prompt).strip()
         if s == 'ok':
@@ -435,11 +408,11 @@ Format of the BODY section:
   * Trailing whitespace is stripped.  Leading whitespace is preserved.
   * Empty lines between non-empty lines are preserved.
     Trailing empty lines are stripped.
-  * The BODY mustn't start with "Issue #", "bpo-", or "- ".
+  * The BODY mustn't start with "Issue #", "gh-", or "- ".
     (This formatting will be inserted when rendering the final output.)
   * Lines longer than 76 characters will be wordwrapped.
       * In the final output, the first line will have
-        "- bpo-<bpo-number>: " inserted at the front,
+        "- gh-issue-<gh-issue-number>: " inserted at the front,
         and subsequent lines will have two spaces inserted
         at the front.
 
@@ -450,11 +423,11 @@ also terminates the last ENTRY.
 
 The format of a "next" file is exactly the same, except that we're storing
 four pieces of metadata in the filename instead of in the metadata section.
-Those four pieces of metadata are: section, bpo, date, and nonce.
+Those four pieces of metadata are: section, gh-issue, date, and nonce.
 
 -----------------------------------------------------------------------------
 
-In addition to the four conventional metadata (section, bpo, date, and nonce),
+In addition to the four conventional metadata (section, gh-issue, date, and nonce),
 there are two additional metadata used per-version: "release date" and
 "no changes".  These may only be present in the metadata block in the *first*
 blurb in a blurb file.
@@ -463,7 +436,7 @@ blurb in a blurb file.
     for this version.  When used, there are two more things that must be
     true about the the blurb file:
       * There should only be one entry inside the blurb file.
-      * That entry's bpo number must be 0.
+      * That entry's gh-issue number must be 0.
 
 """
 
@@ -483,7 +456,7 @@ class Blurbs(list):
         line_number = None
 
         def throw(s):
-            raise BlurbError(f("Error in {filename}:{line_number}:\n{s}"))
+            raise BlurbError(f"Error in {filename}:{line_number}:\n{s}")
 
         def finish_entry():
             nonlocal body
@@ -494,8 +467,8 @@ class Blurbs(list):
             if not body:
                 throw("Blurb 'body' text must not be empty!")
             text = textwrap_body(body)
-            for naughty_prefix in ("- ", "Issue #", "bpo-"):
-                if text.startswith(naughty_prefix):
+            for naughty_prefix in ("- ", "Issue #", "bpo-", "gh-", "gh-issue-"):
+                if re.match(naughty_prefix, text, re.I):
                     throw("Blurb 'body' can't start with " + repr(naughty_prefix) + "!")
 
             no_changes = metadata.get('no changes')
@@ -507,11 +480,19 @@ class Blurbs(list):
                 elif section not in sections:
                     throw("Invalid 'section'!  You must use one of the predefined sections.")
 
-            bpo = None
-            try:
-                bpo = int(metadata.get('bpo'))
-            except (TypeError, ValueError):
-                throw("Invalid bpo issue number! (" + repr(bpo) + ")")
+            issue_number = None
+
+            if metadata.get("gh-issue") is not None:
+                try:
+                    issue_number = int(metadata.get('gh-issue'))
+                except (TypeError, ValueError):
+                    throw("Invalid GitHub issue number! (" + repr(issue_number) + ")")
+            elif metadata.get("bpo") is not None:
+                try:
+                    issue_number = int(metadata.get('bpo'))
+                except (TypeError, ValueError):
+                    throw("Invalid bpo issue number! (" + repr(issue_number) + ")")
+
 
             self.append((metadata, text))
             metadata = {}
@@ -525,7 +506,7 @@ class Blurbs(list):
                     line = line[2:].strip()
                     name, colon, value = line.partition(":")
                     assert colon
-                    name = name.strip()
+                    name = name.lower().strip()
                     value = value.strip()
                     if name in metadata:
                         throw("Blurb metadata sets " + repr(name) + " twice!")
@@ -548,7 +529,7 @@ Read a blurb file.
 
 Broadly equivalent to blurb.parse(open(filename).read()).
         """
-        with open(filename, "rt", encoding="utf-8") as file:
+        with open(filename, encoding="utf-8") as file:
             text = file.read()
         self.parse(text, metadata=metadata, filename=filename)
 
@@ -563,7 +544,7 @@ Broadly equivalent to blurb.parse(open(filename).read()).
                 add_separator = True
             if metadata:
                 for name, value in sorted(metadata.items()):
-                    add(f(".. {name}: {value}\n"))
+                    add(f".. {name}: {value}\n")
                 add("\n")
             add(textwrap_body(body))
         return "".join(output)
@@ -585,16 +566,16 @@ Returns a dict.
         components = filename.split(os.sep)
         section, filename = components[-2:]
         section = unsanitize_section(section)
-        assert section in sections, f("Unknown section {section}")
+        assert section in sections, f"Unknown section {section}"
 
         fields = [x.strip() for x in filename.split(".")]
-        assert len(fields) >= 4, f("Can't parse 'next' filename! filename {filename!r} fields {fields}")
+        assert len(fields) >= 4, f"Can't parse 'next' filename! filename {filename!r} fields {fields}"
         assert fields[-1] == "rst"
 
         metadata = {"date": fields[0], "nonce": fields[-2], "section": section}
 
         for field in fields[1:-2]:
-            for name in ("bpo",):
+            for name in ("gh-issue","bpo"):
                 _, got, value = field.partition(name + "-")
                 if got:
                     metadata[name] = value.strip()
@@ -615,6 +596,7 @@ Returns a dict.
         metadata, body = self[-1]
         assert 'section' in metadata
         for name, default in (
+            ("gh-issue", "0"),
             ("bpo", "0"),
             ("date", sortable_datetime()),
             ("nonce", nonceify(body)),
@@ -630,8 +612,12 @@ Returns a dict.
         metadata, body = self[-1]
         metadata['section'] = sanitize_section(metadata['section'])
         metadata['root'] = root
-        path = "{root}/Misc/NEWS.d/next/{section}/{date}.bpo-{bpo}.{nonce}.rst".format_map(metadata)
-        for name in "root section date bpo nonce".split():
+        if int(metadata["gh-issue"]) > 0 :
+            path = "{root}/Misc/NEWS.d/next/{section}/{date}.gh-issue-{gh-issue}.{nonce}.rst".format_map(metadata)
+        elif int(metadata["bpo"]) > 0:
+            # assume it's a GH issue number
+            path = "{root}/Misc/NEWS.d/next/{section}/{date}.bpo-{bpo}.{nonce}.rst".format_map(metadata)
+        for name in "root section date gh-issue bpo nonce".split():
             del metadata[name]
         return path
 
@@ -705,12 +691,12 @@ class TestParserFailures(TestParserPasses):
     def filename_test(self, filename):
         b = Blurbs()
         with self.assertRaises(Exception):
-            b.read(filename)
+            b.load(filename)
 
 
 
 def run(s):
-    process = subprocess.run(s.split(), stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    process = subprocess.run(s.split(), capture_output=True)
     process.check_returncode()
     return process.stdout.decode('ascii')
 
@@ -738,7 +724,7 @@ def chdir_to_repo_root():
         def test_first_line(filename, test):
             if not os.path.exists(filename):
                 return False
-            with open(filename, "rt") as file:
+            with open(filename) as file:
                 lines = file.read().split('\n')
                 if not (lines and test(lines[0])):
                     return False
@@ -777,7 +763,7 @@ def subcommand(fn):
 def get_subcommand(subcommand):
     fn = subcommands.get(subcommand)
     if not fn:
-        error(f("Unknown subcommand: {subcommand}\nRun 'blurb help' for help."))
+        error(f"Unknown subcommand: {subcommand}\nRun 'blurb help' for help.")
     return fn
 
 
@@ -839,19 +825,19 @@ If subcommand is not specified, prints one-line summaries for every command.
     for name, p in inspect.signature(fn).parameters.items():
         if p.kind == inspect.Parameter.KEYWORD_ONLY:
             short_option = name[0]
-            options.append(f(" [-{short_option}|--{name}]"))
+            options.append(f" [-{short_option}|--{name}]")
         elif p.kind == inspect.Parameter.POSITIONAL_OR_KEYWORD:
             positionals.append(" ")
             has_default = (p.default != inspect._empty)
             if has_default:
                 positionals.append("[")
                 nesting += 1
-            positionals.append(f("<{name}>"))
+            positionals.append(f"<{name}>")
     positionals.append("]" * nesting)
 
 
     parameters = "".join(options + positionals)
-    print(f("blurb {subcommand}{parameters}"))
+    print(f"blurb {subcommand}{parameters}")
     print()
     print(doc)
     sys.exit(0)
@@ -919,14 +905,14 @@ Add a blurb (a Misc/NEWS entry) to the current CPython repo.
             # my editor likes to strip trailing whitespace from lines.
             # normally this is a good idea.  but in the case of the template
             # it's unhelpful.
-            # so, manually ensure there's a space at the end of the bpo line.
+            # so, manually ensure there's a space at the end of the gh-issue line.
             text = template
 
-            bpo_line = ".. bpo:"
-            without_space = "\n" + bpo_line + "\n"
-            with_space = "\n" + bpo_line + " \n"
+            issue_line = ".. gh-issue:"
+            without_space = "\n" + issue_line + "\n"
+            with_space = "\n" + issue_line + " \n"
             if without_space not in text:
-                sys.exit("Can't find BPO line to ensure there's a space on the end!")
+                sys.exit("Can't find gh-issue line to ensure there's a space on the end!")
             text = text.replace(without_space, with_space)
             file.write(text)
 
@@ -942,7 +928,7 @@ Add a blurb (a Misc/NEWS entry) to the current CPython repo.
     else:
         args = list(shlex.split(editor))
         if not shutil.which(args[0]):
-            sys.exit(f("Invalid GIT_EDITOR / EDITOR value: {editor}"))
+            sys.exit(f"Invalid GIT_EDITOR / EDITOR value: {editor}")
     args.append(tmp_path)
 
     while True:
@@ -962,7 +948,7 @@ Add a blurb (a Misc/NEWS entry) to the current CPython repo.
 
         if failure:
             print()
-            print(f("Error: {failure}"))
+            print(f"Error: {failure}")
             print()
             try:
                 prompt("Hit return to retry (or Ctrl-C to abort)")
@@ -996,20 +982,20 @@ This is used by the release manager when cutting a new release.
     if existing_filenames:
         error("Sorry, can't handle appending 'next' files to an existing version (yet).")
 
-    output = f("Misc/NEWS.d/{version}.rst")
+    output = f"Misc/NEWS.d/{version}.rst"
     filenames = glob_blurbs("next")
     blurbs = Blurbs()
     date = current_date()
 
     if not filenames:
-        print(f("No blurbs found.  Setting {version} as having no changes."))
-        body = f("There were no new changes in version {version}.\n")
-        metadata = {"no changes": "True", "bpo": "0", "section": "Library", "date": date, "nonce": nonceify(body)}
+        print(f"No blurbs found.  Setting {version} as having no changes.")
+        body = f"There were no new changes in version {version}.\n"
+        metadata = {"no changes": "True", "gh-issue": "0", "section": "Library", "date": date, "nonce": nonceify(body)}
         blurbs.append((metadata, body))
     else:
         no_changes = None
         count = len(filenames)
-        print(f('Merging {count} blurbs to "{output}".'))
+        print(f'Merging {count} blurbs to "{output}".')
 
         for filename in filenames:
             if not filename.endswith(".rst"):
@@ -1026,14 +1012,14 @@ This is used by the release manager when cutting a new release.
     flush_git_add_files()
 
     how_many = len(filenames)
-    print(f("Removing {how_many} 'next' files from git."))
+    print(f"Removing {how_many} 'next' files from git.")
     git_rm_files.extend(filenames)
     flush_git_rm_files()
 
     # sanity check: ensuring that saving/reloading the merged blurb file works.
     blurbs2 = Blurbs()
     blurbs2.load(output)
-    assert blurbs2 == blurbs, f("Reloading {output} isn't reproducible?!")
+    assert blurbs2 == blurbs, f"Reloading {output} isn't reproducible?!"
 
     print()
     print("Ready for commit.")
@@ -1064,11 +1050,15 @@ To force it to overwrite, use -f.
         builtins.print("You already have a", repr(output), "file.")
         require_ok("Type ok to overwrite")
 
-    news = open(output, "wt", encoding="utf-8")
+    write_news(output, versions=versions)
+
+
+def write_news(output, *, versions):
+    buff = io.StringIO()
 
     def print(*a, sep=" "):
         s = sep.join(str(x) for x in a)
-        return builtins.print(s, file=news)
+        return builtins.print(s, file=buff)
 
     print ("""
 +++++++++++
@@ -1104,7 +1094,7 @@ Python News
         metadata, body = blurbs[0]
         release_date = metadata["release date"]
 
-        print(f("*Release date: {release_date}*"))
+        print(f"*Release date: {release_date}*")
         print()
 
         if "no changes" in metadata:
@@ -1120,16 +1110,34 @@ Python News
                 print(section)
                 print("-" * len(section))
                 print()
+            if metadata.get("gh-issue"):
+                issue_number = metadata['gh-issue']
+                if int(issue_number):
+                    body = "gh-issue-" + issue_number + ": " + body
+            elif metadata.get("bpo"):
+                issue_number = metadata['bpo']
+                if int(issue_number):
+                    body = "bpo-" + issue_number + ": " + body
 
-            bpo = metadata['bpo']
-            if int(bpo):
-                body = "bpo-" + bpo + ": " + body
             body = "- " + body
             text = textwrap_body(body, subsequent_indent='  ')
             print(text)
     print()
     print("**(For information about older versions, consult the HISTORY file.)**")
-    news.close()
+
+
+    new_contents = buff.getvalue()
+
+    # Only write in `output` if the contents are different
+    # This speeds up subsequent Sphinx builds
+    try:
+        previous_contents = Path(output).read_text(encoding="UTF-8")
+    except (FileNotFoundError, UnicodeError):
+        previous_contents = None
+    if new_contents != previous_contents:
+        Path(output).write_text(new_contents, encoding="UTF-8")
+    else:
+        builtins.print(output, "is already up to date")
 
 
 git_add_files = []
@@ -1172,11 +1180,11 @@ Creates and populates the Misc/NEWS.d directory tree.
 
     for section in sections:
         dir_name = sanitize_section(section)
-        dir_path = f("NEWS.d/next/{dir_name}")
+        dir_path = f"NEWS.d/next/{dir_name}"
         safe_mkdir(dir_path)
-        readme_path = f("NEWS.d/next/{dir_name}/README.rst")
+        readme_path = f"NEWS.d/next/{dir_name}/README.rst"
         with open(readme_path, "wt", encoding="utf-8") as readme:
-            readme.write(f("Put news entry ``blurb`` files for the *{section}* section in this directory.\n"))
+            readme.write(f"Put news entry ``blurb`` files for the *{section}* section in this directory.\n")
         git_add_files.append(dir_path)
         git_add_files.append(readme_path)
     flush_git_add_files()
@@ -1197,7 +1205,7 @@ Removes blurb data files, for building release tarballs/installers.
 #    """
 #    Test function for blurb command-line processing.
 #    """
-#    print(f("arg: boolean {boolean} option {option}"))
+#    print(f"arg: boolean {boolean} option {option}")
 
 
 @subcommand
@@ -1230,7 +1238,7 @@ Also runs "blurb populate" for you.
     blurbs = Blurbs()
 
     accumulator = []
-    bpo = "0"
+    issue_number = "0"
     serial_number = 9999
     version = None
     release_date = None
@@ -1245,7 +1253,7 @@ Also runs "blurb populate" for you.
     def flush_blurb():
         nonlocal accumulator
         nonlocal serial_number
-        nonlocal bpo
+        nonlocal issue_number
         nonlocal release_date
         nonlocal see_also
         nonlocal no_changes
@@ -1276,13 +1284,13 @@ Also runs "blurb populate" for you.
                             field = field[1:]
                         try:
                             int(field)
-                            field = "bpo-" + field
+                            field = "gh-issue" + field
                         except ValueError:
                             pass
                         fields.append(field)
                     see_also = ", ".join(fields)
                     # print("see_also: ", repr(see_also))
-                    accumulator.append(f("(See also: {see_also})"))
+                    accumulator.append(f"(See also: {see_also})")
                     see_also = None
                 if not accumulator:
                     return
@@ -1291,7 +1299,7 @@ Also runs "blurb populate" for you.
 
                 body = "\n".join(accumulator) + "\n"
                 metadata = {}
-                metadata["bpo"] = bpo
+                metadata["gh-issue"] = issue_number
                 metadata["date"] = str(serial_number)
                 if section:
                     metadata["section"] = section
@@ -1315,7 +1323,7 @@ Also runs "blurb populate" for you.
                 blurbs.append((metadata, body))
                 blurb_count += 1
 
-            bpo = "0"
+            issue_number = "0"
             serial_number -= 1
             accumulator.clear()
 
@@ -1328,8 +1336,8 @@ Also runs "blurb populate" for you.
         if version is None:
             assert not blurbs, "version should only be None initially, we shouldn't have blurbs yet"
             return
-        assert blurbs, f("No blurbs defined when flushing version {version}!")
-        output = f("NEWS.d/{version}.rst")
+        assert blurbs, f"No blurbs defined when flushing version {version}!"
+        output = f"NEWS.d/{version}.rst"
 
         if released:
             # saving merged blurb file for version, e.g. Misc/NEWS.d/3.7.0a1.rst
@@ -1338,14 +1346,14 @@ Also runs "blurb populate" for you.
         else:
             # saving a million old-school blurb next files
             # with serial numbers instead of dates
-            # e.g. Misc/NEWS.d/next/IDLE/094.bpo-25514.882pXa.rst
+            # e.g. Misc/NEWS.d/next/IDLE/094.gh-issue-25514.882pXa.rst
             filenames = blurbs.save_split_next()
             git_add_files.extend(filenames)
             released = True
         blurbs.clear()
         version_count += 1
 
-    with open("NEWS", "rt", encoding="utf-8") as file:
+    with open("NEWS", encoding="utf-8") as file:
         for line_number, line in enumerate(file):
             line = line.rstrip()
 
@@ -1369,7 +1377,7 @@ Also runs "blurb populate" for you.
                     line = new
             # 2. unusual indenting
             _line = line.lstrip()
-            if _line.startswith(("- Issue #", "- bpo-")):
+            if _line.startswith(("- Issue #", "- gh-issue-")):
                 line = _line
             if _line == ".characters() and ignorableWhitespace() methods.  Original patch by Sebastian":
                 line = " " + line
@@ -1447,11 +1455,11 @@ Also runs "blurb populate" for you.
             elif line.startswith("- Issue #9516: Issue #9516: avoid errors in sysconfig when MACOSX_DEPLOYMENT_TARGET"):
                 line = "- Issue #9516 and Issue #9516: avoid errors in sysconfig when MACOSX_DEPLOYMENT_TARGET"
             elif line.title().startswith(("- Request #", "- Bug #", "- Patch #", "- Patches #")):
-                # print(f("FIXING LINE {line_number}: {line!r}"))
+                # print(f"FIXING LINE {line_number}: {line!r}")
                 line = "- Issue #" + line.partition('#')[2]
-                # print(f("FIXED LINE {line_number}: {line!r}"))
+                # print(f"FIXED LINE {line_number}: {line!r}")
             # else:
-            #     print(f("NOT FIXING LINE {line_number}: {line!r}"))
+            #     print(f"NOT FIXING LINE {line_number}: {line!r}")
 
 
             # 4. determine the actual content of the line
@@ -1511,54 +1519,54 @@ Also runs "blurb populate" for you.
                     line = line.lstrip()
                     if line.startswith("#"):
                         line = line[1:].lstrip()
-                    parse_bpo = True
-                elif line.startswith("bpo-"):
-                    line = line[4:]
-                    parse_bpo = True
+                    parse_issue = True
+                elif line.startswith("gh-issue"):
+                    line = line[8:]
+                    parse_issue = True
                 else:
-                    # print(f("[[{line_number:8} no bpo]] {line}"))
-                    parse_bpo = False
-                if parse_bpo:
+                    # print(f"[[{line_number:8} no gh]] {line}")
+                    parse_issue = False
+                if parse_issue:
                     # GAAAH
                     if line == "17500, and https://github.com/python/pythondotorg/issues/945: Remove":
                         line = "Remove"
-                        bpo = "17500"
+                        issue = "17500"
                         see_also = "https://github.com/python/pythondotorg/issues/945"
                     else:
-                        bpo, colon, line = line.partition(":")
+                        issue, colon, line = line.partition(":")
                         line = line.lstrip()
-                        bpo, comma, see_also = bpo.partition(",")
+                        issue, comma, see_also = issue.partition(",")
                         if comma:
                             see_also = see_also.strip()
-                            # if it's just an integer, add bpo- to the front
+                            # if it's just an integer, add gh-issue to the front
                             try:
                                 int(see_also)
-                                see_also = "bpo-" + see_also
+                                see_also = "gh-issue-" + see_also
                             except ValueError:
                                 pass
                         else:
                             # - Issue #21529 (CVE-2014-4616)
-                            bpo, space_paren, see_also = bpo.partition(" (")
+                            issue, space_paren, see_also = issue.partition(" (")
                             if space_paren:
                                 see_also = see_also.rstrip(")")
                             else:
                                 # - Issue #19544 and Issue #1180:
-                                bpo, space_and, see_also = bpo.partition(" and ")
+                                issue, space_and, see_also = issue.partition(" and ")
                                 if not space_and:
-                                    bpo, space_and, see_also = bpo.partition(" & ")
+                                    issue, space_and, see_also = issue.partition(" & ")
                                 if space_and:
-                                    see_also = see_also.replace("Issue #", "bpo-").strip()
+                                    see_also = see_also.replace("Issue #", "gh-issue-").strip()
                                 else:
                                     # - Issue #5258/#10642: if site.py
-                                    bpo, slash, see_also = bpo.partition("/")
+                                    issue, slash, see_also = issue.partition("/")
                                     if space_and:
-                                        see_also = see_also.replace("#", "bpo-").strip()
+                                        see_also = see_also.replace("#", "gh-").strip()
                     try:
-                        int(bpo) # this will throw if it's not a legal int
+                        int(issue) # this will throw if it's not a legal int
                     except ValueError:
-                        sys.exit(f("Couldn't convert bpo number to int on line {line_number}! {bpo!r}"))
+                        sys.exit(f"Couldn't convert issue number to int on line {line_number}! {issue!r}")
                     if see_also == "partially":
-                        sys.exit(f("What the hell on line {line_number}! {bpo!r}"))
+                        sys.exit(f"What the hell on line {line_number}! {issue!r}")
 
             # 4.6.1 continuation of blurb
             elif line.startswith("  "):
@@ -1567,7 +1575,7 @@ Also runs "blurb populate" for you.
             elif line.startswith(" * "):
                 line = line[3:]
             elif line:
-                sys.exit(f("Didn't recognize line {line_number}! {line!r}"))
+                sys.exit(f"Didn't recognize line {line_number}! {line!r}")
             # only add blank lines if we have an initial line in the accumulator
             if line or accumulator:
                 accumulator.append(line)
@@ -1579,7 +1587,7 @@ Also runs "blurb populate" for you.
     git_rm_files.append("NEWS")
     flush_git_rm_files()
 
-    print(f("Wrote {blurb_count} news items across {version_count} versions."))
+    print(f"Wrote {blurb_count} news items across {version_count} versions.")
     print()
     print("Ready for commit.")
 
@@ -1628,10 +1636,10 @@ def main():
         def handle_option(s, dict):
             name = dict.get(s, None)
             if not name:
-                sys.exit(f('blurb: Unknown option for {subcommand}: "{s}"'))
+                sys.exit(f'blurb: Unknown option for {subcommand}: "{s}"')
             kwargs[name] = not kwargs[name]
 
-        # print(f("short_options {short_options} long_options {long_options}"))
+        # print(f"short_options {short_options} long_options {long_options}")
         for a in args:
             if done_with_options:
                 filtered_args.append(a)
@@ -1665,7 +1673,7 @@ def main():
             # whoops, must be a real type error, reraise
             raise e
 
-        how_many = f("{specified} argument")
+        how_many = f"{specified} argument"
         if specified != 1:
             how_many += "s"
 
@@ -1676,12 +1684,12 @@ def main():
                 middle = "requires"
             else:
                 plural = "" if required == 1 else "s"
-                middle = f("requires at least {required} argument{plural} and at most")
-            middle += f(" {total} argument")
+                middle = f"requires at least {required} argument{plural} and at most"
+            middle += f" {total} argument"
             if total != 1:
                 middle += "s"
 
-        print(f('Error: Wrong number of arguments!\n\nblurb {subcommand} {middle},\nand you specified {how_many}.'))
+        print(f'Error: Wrong number of arguments!\n\nblurb {subcommand} {middle},\nand you specified {how_many}.')
         print()
         print("usage: ", end="")
         help(subcommand)
